@@ -291,27 +291,29 @@ class MenuWin( object ):
         self.mainwin.window.connect( "size-allocate", lambda *args: self.positionMenu() )
         self.mainwin.window.connect( "focus-out-event", lambda *args: self.button.set_name("ButtonApplet") )
 
-        self.bind_hot_key()
+        if self.keybinder is not None:
+            self.bind_hot_key()
         self.applet.set_can_focus(False)
 
         self.pointerMonitor = pointerMonitor.PointerMonitor()
-        self.pointerMonitor.connect("activate", self.onPointerOutside)
+        if self.pointerMonitor is not None:
+            self.pointerMonitor.connect("activate", self.onPointerOutside)
         return False
 
     def onWindowMap( self, *args ):
         self.applet.get_style_context().set_state( Gtk.StateFlags.SELECTED )
         if self.keybinder == None:
             return
-        else:
-            self.keybinder.set_focus_window( self.mainwin.window.get_window() )
+
+        self.keybinder.set_focus_window( self.mainwin.window.get_window() )
         return False
 
     def onWindowUnmap( self, *args ):
         self.applet.get_style_context().set_state( Gtk.StateFlags.NORMAL )
         if self.keybinder == None:
             return
-        else:
-            self.keybinder.set_focus_window()
+        
+        self.keybinder.set_focus_window()
         return False
 
     def onRealize( self, *args):
@@ -331,9 +333,9 @@ class MenuWin( object ):
     def changeIcon(self, settings, key, args = None):
         self.panel_size = self.settings_panel.get_int("size")
         self.pixbuf = GdkPixbuf.Pixbuf.new_from_file("/usr/share/ukui-menu/icons/start.svg")
-        self.pixbuf = self.pixbuf.scale_simple(self.panel_size, self.panel_size, 2)
+        self.pixbuf = self.pixbuf.scale_simple(self.panel_size - 5, self.panel_size - 5, 2)
         self.button_icon.set_from_pixbuf(self.pixbuf)
-        self.button_box.set_size_request(self.panel_size + 10, -1)
+        self.button_box.set_size_request(self.panel_size + 20, -1)
         Gdk.flush()
 
     def createPanelButton( self ):
@@ -353,7 +355,7 @@ class MenuWin( object ):
             print (e)
 
         self.pixbuf = GdkPixbuf.Pixbuf.new_from_file("/usr/share/ukui-menu/icons/start.svg")
-        self.pixbuf = self.pixbuf.scale_simple(self.panel_size, self.panel_size, 2)
+        self.pixbuf = self.pixbuf.scale_simple(self.panel_size - 5, self.panel_size - 5, 2)
         self.button_icon = Gtk.Image.new()
         self.button_icon.set_from_pixbuf(self.pixbuf)
         self.button_icon.set_tooltip_text(_("Start"))
@@ -361,7 +363,7 @@ class MenuWin( object ):
         self.button.set_name("ButtonApplet")
         self.button.set_image(self.button_icon)
         self.button_box = Gtk.Box()
-        self.button_box.set_size_request(self.panel_size + 10, -1)
+        self.button_box.set_size_request(self.panel_size + 20, -1)
         self.button_box.pack_start( self.button , True, True, 0)
         self.button_icon.set_padding( 0, 0 )
 
